% Use Monte Carlo sampling to compute number of avalanches
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%      Markovian Dynamics on Reaction Networks       %%%%%%%%%%%%
%%%%%%%%%%%             Example: Neural dynamics               %%%%%%%%%%%%
%%%%%%%%%%%                AVALANCHE ANALYSIS                  %%%%%%%%%%%%
%%%%%%%%%%%            Authors: Jenkinson/Goutsias             %%%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 04/21/2012             %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function numAval = aveaval(h,nu_E,nu_I,gamma,tf,L,monteSamps)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

M       =  4;         % number of reactions 
N       =  2;         % number of species 
yinit   = [0 0]';

numAval = 0;

for iter = 1:monteSamps

    %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%% MONTE CARLO ITERATIONS
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %

    t = 0;
    Z = repmat(0,M,1);
    Y = repmat(0,N,1);
    
    while t < tf

        phi = nu_E*Y(1)+nu_I*Y(2)+h;  % synaptic input to neurons

        %
        % propensity functions
        %
        propensity(1) = (L/2-Y(1))*max(tanh(phi),0);
        propensity(2) = gamma*Y(1);
        propensity(3) = (L/2-Y(2))*max(tanh(phi),0);
        propensity(4) = gamma*Y(2);

        %
        % Update state
        %
        astr = sum(propensity);
        if ~astr
            t = tf;
        else
            tau  = exprnd(inv(astr));
            t    = t + tau;
            m    = find(cumsum(propensity) > astr*rand, 1 );
            Z(m) = Z(m) + 1;
        end
        Y(1) = yinit(1) + Z(1) - Z(2);
        Y(2) = yinit(2) + Z(3) - Z(4);
        if sum(Y)==0
            numAval = numAval + 1; % started at the origin, number of avalanches 
                                   % is given by the number of returns to origin
        end
    end 

end

numAval = numAval/monteSamps;