% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%     Markovian Dynamics on Reaction Networks        %%%%%%%%%%%%
%%%%%%%%%%%               OPINION FORMATION                    %%%%%%%%%%%%
%%%%%%%%%%%          MOMENT APPROXIMATION METHOD               %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 04/18/2012                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Compute the RHS of the differential equations
%
function [ dudt_dcdt ] = socialRHS(u_c,k1,k2,a1,a2,a3,L,useJensensINEQ)

dudt_dcdt = zeros(4+4*4,1);
dCmat_dt  = zeros(4,4);

muVec = u_c(1:4);
Cmat  = reshape(u_c(5:end),1,4,4); 

%
% Compute the hessians and the gradients
%

[alpha, h_m1_m2, h_m_m1_m2] = compHessGrad(muVec,k1,k2,a1,a2,a3,L);

%
% Compute RHS of mean equations
%
if useJensensINEQ
    dudt_dcdt(1) = alpha(1) + max(0, .5*sum(sum(Cmat.*h_m_m1_m2(1,:,:))) );
    dudt_dcdt(2) = alpha(2) + max(0, .5*sum(sum(Cmat.*h_m_m1_m2(2,:,:))) );
    dudt_dcdt(3) = alpha(3) + max(0, .5*sum(sum(Cmat.*h_m_m1_m2(3,:,:))) );
    dudt_dcdt(4) = alpha(4) + max(0, .5*sum(sum(Cmat.*h_m_m1_m2(4,:,:))) );
else
    dudt_dcdt(1) = alpha(1) + .5*sum(sum(Cmat.*h_m_m1_m2(1,:,:))) ;
    dudt_dcdt(2) = alpha(2) + .5*sum(sum(Cmat.*h_m_m1_m2(2,:,:))) ;
    dudt_dcdt(3) = alpha(3) + .5*sum(sum(Cmat.*h_m_m1_m2(3,:,:))) ;
    dudt_dcdt(4) = alpha(4) + .5*sum(sum(Cmat.*h_m_m1_m2(4,:,:))) ;    
end
    
%
% Compute RHS of covariance equations
%

for m = 1:4
    for mPrime = 1:4
        summand = 0;
        for m1=1:4
            summand = summand + h_m1_m2(mPrime,m1)*Cmat(1,m,m1) + h_m1_m2(m,m1)*Cmat(1,mPrime,m1);
        end
        dCmat_dt(m,mPrime) = dudt_dcdt(m)*(m==mPrime) + summand;
    end
end

dudt_dcdt(5:end) = reshape(dCmat_dt,4*4,1);